@@ -5,10 +5,10 @@ from pettingzoo.utils.to_parallel import parallel_wrapper_fn
 
 class raw_env(SimpleEnv):
 
-    def __init__(self, seed=None, num_good=1, num_adversaries=3, num_obstacles=2, max_frames=100):
+    def __init__(self, num_good=1, num_adversaries=3, num_obstacles=2, max_frames=100):
         scenario = Scenario()
         world = scenario.make_world(num_good, num_adversaries, num_obstacles)
-        super().__init__(scenario, world, max_frames, seed)
+        super().__init__(scenario, world, max_frames)
 
 
 env = make_env(raw_env)
