@@ -23,21 +23,21 @@ parameterized_envs = [
     (combat_tank_v0.env, dict(is_invisible=True)),
     (combat_tank_v0.env, dict(billiard_hit=True)),
 
-    (maze_craze_v0.env, dict(game_version="race")),
-    (maze_craze_v0.env, dict(game_version="capture")),
-    (maze_craze_v0.env, dict(visibilty_level=1)),
-    (maze_craze_v0.env, dict(visibilty_level=3)),
+    (maze_craze_v1.env, dict(game_version="race")),
+    (maze_craze_v1.env, dict(game_version="capture")),
+    (maze_craze_v1.env, dict(visibilty_level=1)),
+    (maze_craze_v1.env, dict(visibilty_level=3)),
 
     (space_invaders_v0.env, dict(alternating_control=True,moving_shields=True,zigzaging_bombs=True,fast_bomb=True,invisible_invaders=True)),
 
-    (knights_archers_zombies_v0.env, dict(spawn_rate=50)),
-    (knights_archers_zombies_v0.env, dict(num_knights=4,num_archers=5)),
-    (knights_archers_zombies_v0.env, dict(killable_knights=True, killable_archers=True)),
-    (knights_archers_zombies_v0.env, dict(killable_knights=False, killable_archers=False)),
-    (knights_archers_zombies_v0.env, dict(black_death=False)),
-    (knights_archers_zombies_v0.env, dict(line_death=False)),
-    (knights_archers_zombies_v0.env, dict(pad_observation=False)),
-    (knights_archers_zombies_v0.env, dict(max_frames=100)),
+    (knights_archers_zombies_v2.env, dict(spawn_rate=50)),
+    (knights_archers_zombies_v2.env, dict(num_knights=4,num_archers=5)),
+    (knights_archers_zombies_v2.env, dict(killable_knights=True, killable_archers=True)),
+    (knights_archers_zombies_v2.env, dict(killable_knights=False, killable_archers=False)),
+    (knights_archers_zombies_v2.env, dict(black_death=False)),
+    (knights_archers_zombies_v2.env, dict(line_death=False)),
+    (knights_archers_zombies_v2.env, dict(pad_observation=False)),
+    (knights_archers_zombies_v2.env, dict(max_frames=100)),
 
     (pistonball_v0.env, dict(local_ratio=0.7)),
     (pistonball_v0.env, dict(continuous=True)),
@@ -85,31 +85,27 @@ parameterized_envs = [
     (simple_world_comm_v0.env, dict(num_good=5,num_adversaries=10,num_obstacles=4,num_food=3)),
     (simple_world_comm_v0.env, dict(num_good=1,num_adversaries=1,num_obstacles=1,num_food=1)),
 
-    (multiwalker_v0.env, dict(n_walkers=10)),
-    (multiwalker_v0.env, dict(reward_mech="global")),
-    (multiwalker_v0.env, dict(terminate_on_fall=True)),
-    (multiwalker_v0.env, dict(terminate_on_fall=False)),
+    (multiwalker_v2.env, dict(n_walkers=10)),
+    (multiwalker_v2.env, dict(local_ratio=0.5)),
+    (multiwalker_v2.env, dict(terminate_on_fall=True)),
+    (multiwalker_v2.env, dict(terminate_on_fall=False)),
 
-    (pursuit_v0.env, dict(xs=8,ys=19)),
-    (pursuit_v0.env, dict(reward_mech="local")),
-    (pursuit_v0.env, dict(reward_mech="global")),
-    (pursuit_v0.env, dict(n_evaders=5,n_pursuers=16)),
-    (pursuit_v0.env, dict(obs_range=15)),
-    (pursuit_v0.env, dict(n_catch=3)),
-    (pursuit_v0.env, dict(random_opponents=True)),
-    (pursuit_v0.env, dict(random_opponents=True, max_opponents=15)),
-    (pursuit_v0.env, dict(freeze_evaders=True)),
-    (pursuit_v0.env, dict(train_pursuit=True)),
+    (pursuit_v1.env, dict(x_size=8,y_size=19)),
+    (pursuit_v1.env, dict(local_ratio=0.5)),
+    (pursuit_v1.env, dict(n_evaders=5,n_pursuers=16)),
+    (pursuit_v1.env, dict(obs_range=15)),
+    (pursuit_v1.env, dict(n_catch=3)),
+    (pursuit_v1.env, dict(freeze_evaders=True)),
     # what is up with the ally_layer and opponent_layer parameters?
 
-    (waterworld_v0.env, dict(n_pursuers=3,n_evaders=6)),
-    (waterworld_v0.env, dict(n_coop=1)),
-    (waterworld_v0.env, dict(n_coop=1)),
-    (waterworld_v0.env, dict(n_poison=4)),
-    (waterworld_v0.env, dict(n_sensors=4)),
-    (waterworld_v0.env, dict(terminate_on_fall=False)),
-    (waterworld_v0.env, dict(reward_mech="global")),
-    (waterworld_v0.env, dict(speed_features=False)),
+    (waterworld_v1.env, dict(n_pursuers=3,n_evaders=6)),
+    (waterworld_v1.env, dict(n_coop=1)),
+    (waterworld_v1.env, dict(n_coop=1)),
+    (waterworld_v1.env, dict(n_poison=4)),
+    (waterworld_v1.env, dict(n_sensors=4)),
+    (waterworld_v1.env, dict(terminate_on_fall=False)),
+    (waterworld_v1.env, dict(local_ratio=0.5)),
+    (waterworld_v1.env, dict(speed_features=False)),
 ]
 
 @pytest.mark.parametrize(("env_constr", "kwargs"), parameterized_envs)
