@@ -37,6 +37,9 @@ class BaseWrapper(AECEnv):
         except AttributeError:
             pass
 
+    def seed(self, seed=None):
+        self.env.seed(seed)
+
     def close(self):
         self.env.close()
 
@@ -71,11 +74,13 @@ class AgentIterWrapper(BaseWrapper):
     def __init__(self, env):
         super().__init__(env)
         self._has_updated = False
+        self._is_iterating = False
         self._agent_idxs = {agent: i for i, agent in enumerate(env.agents)}
         # self._was_dones = {agent: False for agent in self.agents}
 
     def reset(self, observe=True):
         self._has_updated = True
+        self._final_rewards = {agent: 0 for agent in self.agents}
         self.old_observation = None
         obs = super().reset(observe)
         self._was_dones = {agent: done for agent, done in self.dones.items()}
@@ -89,22 +94,21 @@ class AgentIterWrapper(BaseWrapper):
         self._has_updated = True
 
         cur_agent = self.agent_selection
-        if self.dones[cur_agent] and not self._was_dones[cur_agent]:
+        if self.agent_selection != self.env.agent_selection:
             self._was_dones[cur_agent] = True
             self.agent_selection = self.env.agent_selection
         else:
             self._was_dones[cur_agent] = self.env.dones[cur_agent]
             super().step(action, False)
 
-        next_agent = self.agent_selection
-        start_idx = self._agent_idxs[cur_agent]
-        end_idx = self._agent_idxs[next_agent]
-        idx = (start_idx + 1) % self.env.num_agents
-        while idx != end_idx:
-            agent = self.agents[idx]
-            idx = (idx + 1) % self.env.num_agents
+        for agent in self.agents:
+            if self.dones[agent] and not self._final_rewards[agent]:
+                self._final_rewards[agent] = self.rewards[agent]
+
+        for agent in self.agents:
             if self.dones[agent] and not self._was_dones[agent]:
                 self.agent_selection = agent
+                self.rewards[agent] = self._final_rewards[agent]
                 break
 
         return super().observe(self.agent_selection) if observe else None
@@ -126,6 +130,7 @@ class AECIterator:
     def __init__(self, env, max_agent_iter):
         self.env = env
         self.iters_til_term = max_agent_iter
+        self.env._is_iterating = True
 
     def __next__(self):
         if self.env._was_dones[self.env.agent_selection] or self.iters_til_term <= 0:
@@ -286,6 +291,10 @@ class OrderEnforcingWrapper(AgentIterWrapper):
         else:
             raise AttributeError("'{}' object has no attribute '{}'".format(type(self).__name__, value))
 
+    def seed(self, seed=None):
+        self._has_reset = False
+        super().seed(seed)
+
     def render(self, mode='human'):
         if not self._has_reset:
             EnvLogger.error_render_before_reset()
